==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-framework-api/src/main/java/org/apache/nifi/bundle/Bundle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.bundle;

/**
 * Represents a bundle that contains one or more extensions.
 */
public class Bundle {

    private final BundleDetails bundleDetails;

    private final ClassLoader classLoader;

    public Bundle(final BundleDetails bundleDetails, final ClassLoader classLoader) {
        this.bundleDetails = bundleDetails;
        this.classLoader = classLoader;

        if (this.bundleDetails == null) {
            throw new IllegalStateException("BundleDetails cannot be null");
        }

        if (this.classLoader == null) {
            throw new IllegalStateException("ClassLoader cannot be null");
        }
    }

    public BundleDetails getBundleDetails() {
        return bundleDetails;
    }

    public ClassLoader getClassLoader() {
        return classLoader;
    }

    @Override
    public String toString() {
        return bundleDetails.toString();
    }
}

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-framework-api/src/main/java/org/apache/nifi/bundle/Bundle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.bundle;

import java.util.Objects;

/**
 * Represents a bundle that contains one or more extensions.
 */
public class Bundle {

    private final BundleDetails bundleDetails;

    private final ClassLoader classLoader;

    public Bundle(final BundleDetails bundleDetails, final ClassLoader classLoader) {
        this.bundleDetails = bundleDetails;
        this.classLoader = classLoader;

        if (this.bundleDetails == null) {
            throw new IllegalStateException("BundleDetails cannot be null");
        }

        if (this.classLoader == null) {
            throw new IllegalStateException("ClassLoader cannot be null");
        }
    }

    public BundleDetails getBundleDetails() {
        return bundleDetails;
    }

    public ClassLoader getClassLoader() {
        return classLoader;
    }

    @Override
    public String toString() {
        return bundleDetails.toString();
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final Bundle bundle = (Bundle) o;
        return Objects.equals(bundleDetails.getCoordinate(), bundle.bundleDetails.getCoordinate()) && Objects.equals(classLoader, bundle.classLoader);
    }

    @Override
    public int hashCode() {
        return Objects.hash(bundleDetails.getCoordinate(), classLoader);
    }
}
